DmChatInput class
Chat composer — wraps DmMarkdownInput with Send/Stop/Attach controls.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DmChatInput
Constructors
-
DmChatInput({Key? key, required DmChatSendCallback onSend, VoidCallback? onStop, ValueChanged<
List< ? onAttach, DmChatUploadAdapter? uploadAdapter, DmMarkdownInputController? controller, bool isStreaming = false, List<DmChatAttachment> >DmChatAttachment> pendingAttachments = const [], ValueChanged<DmChatAttachment> ? onRemoveAttachment, String? placeholder, Widget? leading, Widget? trailing, int minLines = 1, int maxLines = 8, DmChatSubmitShortcut submitShortcut = DmChatSubmitShortcut.cmdEnter}) -
const
Properties
- controller → DmMarkdownInputController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStreaming → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
final
- maxLines → int
-
final
- minLines → int
-
final
-
onAttach
→ ValueChanged<
List< ?DmChatAttachment> > -
final
-
onRemoveAttachment
→ ValueChanged<
DmChatAttachment> ? -
final
- onSend → DmChatSendCallback
-
final
- onStop → VoidCallback?
-
final
-
pendingAttachments
→ List<
DmChatAttachment> -
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submitShortcut → DmChatSubmitShortcut
-
final
- trailing → Widget?
-
final
- uploadAdapter → DmChatUploadAdapter?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DmChatInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited