MermaidLayoutConfig class

Annotations

Constructors

MermaidLayoutConfig({double nodeSpacing = 50, double rankSpacing = 80, double padding = 16, double fontSize = 16, double lineHeight = 1.25, double nodeHorizontalPadding = 18, double nodeVerticalPadding = 12, double minNodeWidth = 64, double minNodeHeight = 44, double? preferredAspectRatio})
const

Properties

fontSize double
final
hashCode int
The hash code for this object.
no setteroverride
lineHeight double
final
minNodeHeight double
final
minNodeWidth double
final
nodeHorizontalPadding double
final
nodeSpacing double
final
nodeVerticalPadding double
final
padding double
final
preferredAspectRatio double?
final
rankSpacing double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override